summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp')
-rw-r--r--TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp114
1 files changed, 57 insertions, 57 deletions
diff --git a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp
index 5bdf9d4daf1..95a91256355 100644
--- a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp
+++ b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_PropertyManager.cpp
@@ -19,11 +19,11 @@ TAO_LB_PropertyManager::TAO_LB_PropertyManager (
void
TAO_LB_PropertyManager::set_default_properties (
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
this->validate_properties (props, ACE_TRY_ENV);
ACE_CHECK;
@@ -35,16 +35,16 @@ TAO_LB_PropertyManager::set_default_properties (
}
}
-LoadBalancing::Properties *
+PortableGroup::Properties *
TAO_LB_PropertyManager::get_default_properties (
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException))
{
ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, guard, this->lock_, 0);
- LoadBalancing::Properties *props = 0;
+ PortableGroup::Properties *props = 0;
ACE_NEW_THROW_EX (props,
- LoadBalancing::Properties (this->default_properties_),
+ PortableGroup::Properties (this->default_properties_),
CORBA::NO_MEMORY (
CORBA::SystemException::_tao_minor_code (
TAO_DEFAULT_MINOR_CODE,
@@ -57,11 +57,11 @@ TAO_LB_PropertyManager::get_default_properties (
void
TAO_LB_PropertyManager::remove_default_properties (
- const LoadBalancing::Properties &props,
+ const PortableGroup::Properties &props,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
this->validate_properties (props, ACE_TRY_ENV);
ACE_CHECK;
@@ -72,11 +72,11 @@ TAO_LB_PropertyManager::remove_default_properties (
void
TAO_LB_PropertyManager::set_type_properties (
const char * /* type_id */,
- const LoadBalancing::Properties & overrides,
+ const PortableGroup::Properties & overrides,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
this->validate_properties (overrides, ACE_TRY_ENV);
ACE_CHECK;
@@ -84,7 +84,7 @@ TAO_LB_PropertyManager::set_type_properties (
ACE_THROW (CORBA::NO_IMPLEMENT ());
}
-LoadBalancing::Properties *
+PortableGroup::Properties *
TAO_LB_PropertyManager::get_type_properties (
const char * /* type_id */,
CORBA::Environment &ACE_TRY_ENV)
@@ -96,11 +96,11 @@ TAO_LB_PropertyManager::get_type_properties (
void
TAO_LB_PropertyManager::remove_type_properties (
const char * /* type_id */,
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
this->validate_properties (props, ACE_TRY_ENV);
ACE_CHECK;
@@ -110,13 +110,13 @@ TAO_LB_PropertyManager::remove_type_properties (
void
TAO_LB_PropertyManager::set_properties_dynamically (
- LoadBalancing::ObjectGroup_ptr /*object_group */,
- const LoadBalancing::Properties & overrides,
+ PortableGroup::ObjectGroup_ptr /*object_group */,
+ const PortableGroup::Properties & overrides,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::ObjectGroupNotFound,
- LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ PortableGroup::ObjectGroupNotFound,
+ PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
this->validate_properties (overrides, ACE_TRY_ENV);
ACE_CHECK;
@@ -124,12 +124,12 @@ TAO_LB_PropertyManager::set_properties_dynamically (
ACE_THROW (CORBA::NO_IMPLEMENT ());
}
-LoadBalancing::Properties *
+PortableGroup::Properties *
TAO_LB_PropertyManager::get_properties (
- LoadBalancing::ObjectGroup_ptr /* object_group */,
+ PortableGroup::ObjectGroup_ptr /* object_group */,
CORBA::Environment &ACE_TRY_ENV)
ACE_THROW_SPEC ((CORBA::SystemException,
- LoadBalancing::ObjectGroupNotFound))
+ PortableGroup::ObjectGroupNotFound))
{
#if 0
TAO_LB_ObjectGroup_Map_Entry *entry =
@@ -141,7 +141,7 @@ TAO_LB_PropertyManager::get_properties (
// ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, property_map_guard, this->lock_, 0);
// Merge the type-properties into the list.
- LoadBalancing::Properties &type_properties;
+ PortableGroup::Properties &type_properties;
if (this->type_properties_.find (entry.in (), type_properties == 0))
{
}
@@ -156,10 +156,10 @@ TAO_LB_PropertyManager::get_properties (
void
TAO_LB_PropertyManager::validate_properties (
- const LoadBalancing::Properties & props,
+ const PortableGroup::Properties & props,
CORBA::Environment &ACE_TRY_ENV)
- ACE_THROW_SPEC ((LoadBalancing::InvalidProperty,
- LoadBalancing::UnsupportedProperty))
+ ACE_THROW_SPEC ((PortableGroup::InvalidProperty,
+ PortableGroup::UnsupportedProperty))
{
// @todo FIXME! Just a hack to get things going...
@@ -170,21 +170,21 @@ TAO_LB_PropertyManager::validate_properties (
"Factories") == 0)
return;
else if (ACE_OS::strcmp (props[i].nam[0].id,
- "InitialNumberReplicas") == 0)
+ "InitialNumberMembers") == 0)
return;
else if (ACE_OS::strcmp (props[i].nam[0].id,
- "MinimumNumberReplicas") == 0)
+ "MinimumNumberMembers") == 0)
return;
else
- ACE_THROW (LoadBalancing::UnsupportedProperty (props[i].nam));
+ ACE_THROW (PortableGroup::UnsupportedProperty (props[i].nam));
}
}
// void
// TAO_LB_PropertyManager::process_criteria (
// const char *type_id,
// const LoadBalancing::Criteria &the_criteria, // IN
// LoadBalancing::Properties &props, // OUT
// CORBA::Environment &ACE_TRY_ENV)
// {
// this->validate_properties (the_criteria, ACE_TRY_ENV);
@@ -198,10 +198,10 @@ TAO_LB_PropertyManager::validate_properties (
// }
// }
-LoadBalancing::InitialNumberReplicas
-TAO_LB_PropertyManager::initial_number_replicas (
+PortableGroup::InitialNumberMembersValue
+TAO_LB_PropertyManager::initial_number_members (
const char * /* type_id */,
- const LoadBalancing::Criteria &the_criteria,
+ const PortableGroup::Criteria &the_criteria,
CORBA::Environment &ACE_TRY_ENV) const
{
// @@ Hack to get things going.
@@ -212,14 +212,14 @@ TAO_LB_PropertyManager::initial_number_replicas (
for (CORBA::ULong i = 0; i < len; ++i)
{
if (ACE_OS::strcmp (the_criteria[i].nam[0].id,
- "InitialNumberReplicas") == 0)
+ "InitialNumberMembers") == 0)
{
- LoadBalancing::InitialNumberReplicas initial_number_replicas = 0;
+ PortableGroup::InitialNumberMembersValue initial_number_members = 0;
- if (the_criteria[i].val >>= initial_number_replicas)
- return initial_number_replicas;
+ if (the_criteria[i].val >>= initial_number_members)
+ return initial_number_members;
else
- ACE_THROW_RETURN (LoadBalancing::InvalidProperty (
+ ACE_THROW_RETURN (PortableGroup::InvalidProperty (
the_criteria[i].nam,
the_criteria[i].val),
0);
@@ -234,10 +234,10 @@ TAO_LB_PropertyManager::initial_number_replicas (
return 0; // @@ FIXME
}
-LoadBalancing::FactoryInfos *
+PortableGroup::FactoryInfos *
TAO_LB_PropertyManager::factory_infos (
const char * /* type_id */,
- const LoadBalancing::Criteria &the_criteria,
+ const PortableGroup::Criteria &the_criteria,
CORBA::Environment &ACE_TRY_ENV) const
{
// @@ Hack to get things going.
@@ -250,16 +250,16 @@ TAO_LB_PropertyManager::factory_infos (
if (ACE_OS::strcmp (the_criteria[i].nam[0].id,
"Factories") == 0)
{
- LoadBalancing::FactoryInfos *tmp = 0;
+ PortableGroup::FactoryInfos *tmp = 0;
if (the_criteria[i].val >>= tmp)
{
// The Any retains ownership of the data, so we need to
// return a copy.
- LoadBalancing::FactoryInfos *factory_infos = 0;
+ PortableGroup::FactoryInfos *factory_infos = 0;
ACE_NEW_THROW_EX (
factory_infos,
- LoadBalancing::FactoryInfos (*tmp),
+ PortableGroup::FactoryInfos (*tmp),
CORBA::NO_MEMORY (
CORBA::SystemException::_tao_minor_code (
TAO_DEFAULT_MINOR_CODE,
@@ -270,7 +270,7 @@ TAO_LB_PropertyManager::factory_infos (
return factory_infos;
}
else
- ACE_THROW_RETURN (LoadBalancing::InvalidProperty (
+ ACE_THROW_RETURN (PortableGroup::InvalidProperty (
the_criteria[i].nam,
the_criteria[i].val),
0);
@@ -289,19 +289,19 @@ TAO_LB_PropertyManager::factory_infos (
#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
// Type-specific property hash map template instantiations
-template class ACE_Hash_Map_Entry<const char *, LoadBalancing::Properties>;
-template class ACE_Hash_Map_Manager_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Base_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
+template class ACE_Hash_Map_Entry<const char *, PortableGroup::Properties>;
+template class ACE_Hash_Map_Manager_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
+template class ACE_Hash_Map_Iterator_Base_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
+template class ACE_Hash_Map_Iterator_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
+template class ACE_Hash_Map_Reverse_Iterator_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
// Type-specific property hash map template instantiations
-#pragma instantiate ACE_Hash_Map_Entry<const char *, LoadBalancing::Properties>
-#pragma instantiate ACE_Hash_Map_Manager_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<const char *, LoadBalancing::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
+#pragma instantiate ACE_Hash_Map_Entry<const char *, PortableGroup::Properties>
+#pragma instantiate ACE_Hash_Map_Manager_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
+#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
+#pragma instantiate ACE_Hash_Map_Iterator_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
+#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<const char *, PortableGroup::Properties, ACE_Hash<const char *>, ACE_Equal_To<const char *>, ACE_Null_Mutex>
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
@@ -170,21 +170,21 @@ TAO_LB_PropertyManager::validate_properties (
// TAO_LB_PropertyManager::process_criteria (
// const char *type_id,
-// const LoadBalancing::Criteria &the_criteria, // IN
-// LoadBalancing::Properties &props, // OUT
+// const PortableGroup::Criteria &the_criteria, // IN
+// PortableGroup::Properties &props, // OUT
// CORBA::Environment &ACE_TRY_ENV)
// {